#include "usdt_tp.h"
#include <stdio.h>

int main()
{
  while (1) {
    myclock();
  }
  return 0;
}
